==> haskell-doctest-0.21.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest
version:              0.21.1
visibility:           public
id:                   doctest-0.21.1-EORXUeRJ7x2AC0KokHSlj0
key:                  doctest-0.21.1-EORXUeRJ7x2AC0KokHSlj0
license:              MIT
copyright:            (c) 2009-2022 Simon Hengel
maintainer:           quasicomputational@gmail.com, Andreas Abel
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    `doctest` is a tool that checks [examples](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810775744)
    and [properties](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810771856)
    in Haddock comments.
    It is similar in spirit to the [popular Python module with the same name](https://docs.python.org/3/library/doctest.html).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  036830f848cb9ef86f7428259ab13911
exposed:              True
exposed-modules:      Test.DocTest
hidden-modules:
    Extract GhcUtil Info Interpreter Language.Haskell.GhciWrapper
    Location Options PackageDBs Parse Property Run Runner
    Runner.Example Util Paths_doctest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-0.21.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-0.21.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-0.21.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest
hs-libraries:         HSdoctest-0.21.1-EORXUeRJ7x2AC0KokHSlj0
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    syb-0.7.2.4-3UNocCME2u02nAWFt1pJGR transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-0.21.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest
version:              0.21.1
visibility:           public
id:                   doctest-0.21.1-FfIrFCWDg62FgAcKxETSKW
key:                  doctest-0.21.1-FfIrFCWDg62FgAcKxETSKW
license:              MIT
copyright:            (c) 2009-2022 Simon Hengel
maintainer:           quasicomputational@gmail.com, Andreas Abel
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/doctest#readme
synopsis:             Test interactive Haskell examples
description:
    `doctest` is a tool that checks [examples](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810775744)
    and [properties](https://www.haskell.org/haddock/doc/html/ch03s08.html#idm140354810771856)
    in Haddock comments.
    It is similar in spirit to the [popular Python module with the same name](https://docs.python.org/3/library/doctest.html).

    Documentation is at <https://github.com/sol/doctest#readme>.

category:             Testing
abi:                  ec05927367fe592105a5b3ada0dcff51
exposed:              True
exposed-modules:      Test.DocTest
hidden-modules:
    Extract GhcUtil Info Interpreter Language.Haskell.GhciWrapper
    Location Options PackageDBs Parse Property Run Runner
    Runner.Example Util Paths_doctest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/doctest-0.21.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/doctest-0.21.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/doctest-0.21.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest
hs-libraries:         HSdoctest-0.21.1-FfIrFCWDg62FgAcKxETSKW
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2 ghc-9.4.8
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj process-1.6.18.0
    syb-0.7.2.4-7JOtjKcEmcW20UWUNnrGCM transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-doctest/html/doctest.haddock
haddock-html:         /usr/share/doc/haskell-doctest/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
